//We always have to include the library
#include "LedControl.h"

/*
 Now we need a LedControl to work with.
 ***** These pin numbers will probably not work with your hardware *****
 pin 12 is connected to the DataIn 
 pin 11 is connected to the CLK 
 pin 10 is connected to LOAD 
 We have only a single MAX72XX.
 */
LedControl lc=LedControl(12,11,10,1);

/* we always wait a bit between updates of the display */
unsigned long delaytime=250;
byte buffer[8]; //Character buffer
void setup() {
  /*
   The MAX72XX is in power-saving mode on startup,
   we have to do a wakeup call
   */
  lc.shutdown(0,false);
  /* Set the brightness to a medium values */
  lc.setIntensity(0,8);
  /* and clear the display */
  lc.clearDisplay(0);
}


/*
 This method will display the characters for the
 word "Arduino" one after the other on digit 0. 
 */
void writeArduinoOn7Segment() {     
  lc.setChar(0,6,'a',false);
  delay(delaytime);
  lc.setRow(0,5,0x05);
  delay(delaytime);
  lc.setChar(0,4,'d',false);
  delay(delaytime);
  lc.setRow(0,3,0x1c);
  delay(delaytime);
  lc.setRow(0,2,B00010000);
  delay(delaytime);
  lc.setRow(0,1,0x15);
  delay(delaytime);
  lc.setRow(0,0,0x1D);
  delay(2000);
  lc.clearDisplay(0);
  delay(delaytime);
} 

/*
 This method will scroll all the hexa-decimal
 numbers and letters on the display. 
 */
void scrollDigits() {
  int i,j;
  for(i=0; i<8; i++) buffer[i]=32;  //Clear buffer
  for(j=0;j<16;j++) {
    for(i=0; i<7; i++) {
      buffer[i] = buffer[i+1];
      lc.setDigit(0,7-i,buffer[i],false);
    }  
    buffer[7] = j;
    lc.setDigit(0,0,j,false);
    delay(delaytime);
  }
  lc.clearDisplay(0);
  delay(delaytime);
}

void displayDate(int year, int month, int day) {
  boolean dp;
  buffer[4]= year%10; year /=10;
  buffer[5]= year%10; year /=10;
  buffer[6]= year%10; 
  buffer[7]= year/10; 
  buffer[2]= month%10;
  buffer[3]= month/10; 
  buffer[0]= day%10;
  buffer[1]= day/10; 
  for(int i=0; i<8; i++) {
    dp = (i==2 || i==4);
    lc.setDigit(0,i,buffer[i],dp); 
  }
  delay(2000);
  lc.clearDisplay(0);
  delay(delaytime);  
}

void displayTime(int hour, int mins, int sec) {
  buffer[7]= hour/10;
  buffer[6]= hour%10;
  buffer[5]= '-'; 
  buffer[4]= mins/10; 
  buffer[3]= mins%10;
  buffer[2]= '-'; 
  buffer[1]= sec/10;
  buffer[0]= sec%10; 
  for(int i=0; i<8; i++) {
    lc.setChar(0,i,buffer[i],false); 
  }
  delay(delaytime);  
}

void loop() { 
  writeArduinoOn7Segment();
  scrollDigits();
  displayDate(2014, 6, 9);
  for(int k=0; k<16; k++) {
    long time = millis()/1000;
    int s = time%60;
    int h = time/3600;
    int m = (time/60)%60;
    displayTime(h,m,s);
    delay(500);
  }
  lc.clearDisplay(0);
  delay(delaytime);   
} 
